function S3DET_v7
%Ersan Turkoglu, November 2, 2008, S3DET_v7, model expoting to winglink is
%on the menu, user has to write real world coordinates and mesh rotation
%from the original winglink model. Remember mesh rot has to be positive NW.
%Program can select which components to be used for pseudosection plotting
%i.e. Diagonals or off diagonals.
%Ersan Turkoglu, April 26, 2008, S3DET_v5, exports edi files from the 3D
%response. you need to have original *.mat file and edis in the same folder.
%Ersan Turkoglu, April 22, 2008, Errorbars are correctly plotted finally
%after 1.7 year
%Ersan Turkoglu, October 10, 2006
%Ersan Turkoglu, version-3==>can handle with rectangular meshes
%Plotting function for wsinv3dmt output files
%Ersan Turkoglu, version-2==>graphically choose profiles and stations to be on them.
%graphically choose slices
%Ersan Turkoglu, version-1==>basic March, 2006
%
%Ersan Turkoglu, University of Alberta, March, 2006
%This program may not be used without permission
%Users agree to report any moderate or major changes made to this program
%contact for permission and technical support: ersan.turkoglu@gmail.com

clear all; close all; clc
global OA x colim sttol pref_strike cmap

pref_strike = 20*pi/180; %Used in pcol_resp
colim=[0-0.15 3+0.15]; % caxis values for color plots
%0.15 to make figures same as pmv* because WS did so...
sttol=10;   %station search tolerance in km; 40 km for NAB
zax=50;   %max depth on sections; 250 for NAB
cmap=jet(24);
cmap([23 21 19 17 15 13 11 9 7 5 3],:)=[];
cmap=flipud(cmap);
centlat=0;%50.7256;  %Keep 0 to plot 3D depth slices in meters.
centlong=0;%-112.8076;  %Keep 0 to plot 3D depth slices in meters.
max_p=710; %maximum profile lenght possible in km
max_d=710; % maximum depth of the profile possible in km
%warning('off');
%################Change Above as needed#####################################
%################Change Above as needed#####################################
%################Change Above as needed#####################################
parfile=0;parfiles=0;
while isequal(parfile,0)
    modelmi=menu('choose','load model','load data only','exit');
    if modelmi==1
        [parfile,outpath] = uigetfile('*model*','pick inversion model file');
        %disp(['reading model file: ',parfile])
        if isequal(parfile,0)
        else
            [niter,RMS,nx,ny,nz,x,y,z,A,NS,EW,ns,nr,np]=load_para(parfile);
        end
    elseif modelmi==2
        disp('loading data and parameters')
        [parfiles,outpaths] = uigetfile({'*.data'},'pick data file');
        if isequal(parfiles,0)
        else
            parfiles=[outpaths,'/',parfiles];
            [NS,EW]=load_init(parfiles);
            break
        end
    else
        return
    end
end
while 1
    if modelmi==2
        plw=3;
    else
        plw=menu('choose','2D sections','3D slices','response','3D view','Isosurface','export to edi','export model for winglink','done');
    end
    if plw==1            %2D sections
        while 1
            plw1=menu('choose','EW-slice','NS-slice','y limits','z limits','done');
            if plw1==5 break; end
            a=A(:,:,1);
            figure(1);hold off; pcolor(y,-x,a)
            title(['slice=',num2str(1),'  ==>  ','depth=',num2str(z(1)),' km']); axis equal; axis tight
            xlabel('Easting (km)'); ylabel('Northing (km)'); colormap(cmap); caxis(colim); colorbar
            hold on; plot(EW,NS,'.k','markersize',12);
            if plw1<3
                plw2=menu('zoom','stations','NO'); axis equal; axis tight; %shading flat
                if plw2==1
                    figure(1);axis([min(EW)-sttol/2 max(EW)+sttol/2 min(NS)-sttol/2 max(NS)+sttol/2]);
                else
                end
            end
            if plw1==1    %East-West
                disp('choosing EW-slice')
                figure(1);[iks,ye]=ginput(1);  %graphically choose the slice to be plotted
                ye=abs(ye-(x)); lye=length(ye); ye=find(ye==min(ye));
                stps=find(NS>x(ye)-sttol & NS<x(ye)+sttol);
                figure(1);plot(EW(stps),NS(stps),'.r','markersize',12)
                b=A(lye-ye,:,:);
                b=reshape(b,ny+1,nz+1);
                figure(1); plot([min(y) max(y)],[x(ye)-sttol,x(ye)-sttol],'r-','linewidth',3)  %draw a line for selected profile
                figure(1); plot([min(y) max(y)],[x(ye)+sttol,x(ye)+sttol],'r-','linewidth',3)  %draw a line for selected profile
                %graphical station selection/unselection
                disp('click for station selection/unselection, use right button to quit')
                while 1
                    figure(1);[exs yes click]=ginput(1);
                    if click==3; break; end
                    stp1=find(NS>yes-sttol/6 & NS<yes+sttol/6 & EW>exs-sttol/6 & EW<exs+sttol/6);
                    if stp1>0
                        dec=find(stps==stp1);
                        if dec>0
                            stps(dec)=[];
                        else
                            stps=[stps;stp1];
                        end
                        figure(1); plot(EW,NS,'.k','markersize',12); plot(EW(stps),NS(stps),'.r','markersize',12)
                    end
                end
                scale=[min(EW(stps))-sttol max(EW(stps))+sttol 0 zax];
                font_n='tahoma';
                font_s=12;
                close all;
                got=get(0,'screensize');
                figure('position',[170 110 got(3)*0.80 got(4)*0.80],'PaperPositionMode','auto');
                set(gca,'fontname',font_n,'FontSize',font_s,'linewidth',1);
                clf
                subplot('position',[0.1 0.2 0.8*abs(scale(2)-scale(1))/max_p abs(scale(4)-scale(3))*0.8/max_d*got(3)/got(4)]);

                pcolor(y,z,b');colormap(cmap); caxis(colim); hold on; set(gca,'YDir','reverse');%set(gca,'XDir','reverse')
                plot(EW(stps),zeros(length(stps)),'kv','markerfacecolor','k','markersize',3);
                axis equal; shading flat; axis(scale); box on;
                title([num2str(ye),'. EW-slice']);
                set(gca,'fontname',font_n,'FontSize',font_s,'linewidth',1);
                xlabel('Easting (m)'); ylabel('Depth (km)'); hold off

                hcb = colorbar('hor','position',[(0.1+0.8*abs(scale(2)-scale(1))/max_p/2-0.125) 0.07 0.25 0.025],...
                    'XTick',[0 0.5,1,1.5,2,2.5,3],...
                    'fontname',font_n,'fontsize',font_s,...
                    'XTickLabel',{'1','3','10','30','100','300','1000'});
                set(get(hcb, 'Title'), 'String', 'Resistivity (\Omegam)','fontsize',12,'fontname',font_n);


            elseif plw1==2 || plw1==3 || plw1==4    %North-South
                if plw1==2
                    disp('choosing NS-slice')
                    figure(1);[iks,ye]=ginput(1);  %graphically choose the slice to be plotted
                    iks=abs(iks-(y));
                    iks=find(iks==min(iks));
                    stps=find(EW>y(iks)-sttol & EW<y(iks)+sttol);
                    figure(1);plot(EW(stps),NS(stps),'.r','markersize',12);
                    b=A(:,iks,:);
                    b=reshape(b,nx+1,nz+1);
                    figure(1); plot([y(iks)-sttol,y(iks)-sttol],[min(x) max(x)],'r-','linewidth',3)  %draw a line for selected profile
                    figure(1); plot([y(iks)+sttol,y(iks)+sttol],[min(x) max(x)],'r-','linewidth',3)  %draw a line for selected profile
                    %graphical station selection/unselection
                    disp('click for station selection/unselection, use right button to quit')
                    while 1
                        figure(1);[exs yes click]=ginput(1);
                        if click==3; break; end
                        stp1=find(NS>yes-sttol/6 & NS<yes+sttol/6 & EW>exs-sttol/6 & EW<exs+sttol/6);
                        if stp1>0
                            dec=find(stps==stp1);
                            if dec>0
                                stps(dec)=[];
                            else
                                stps=[stps;stp1];
                            end
                            figure(1); plot(EW,NS,'.k','markersize',12); plot(EW(stps),NS(stps),'.r','markersize',12)
                        end
                    end
                end
                %same logic as in pmv14
                scale=[min(NS(stps))-sttol max(NS(stps))+sttol 0 zax];
                fsls=NS(stps);
                if plw1==3
                    disp('first and last site locations')
                    disp(fsls)
                    disp('ymin ymax')
                    disp(scale(1:2))
                    scale(1)=input('Enter left edge (km): ');
                    while 1
                        scale(2)=input('Enter right edge (> left edge) (km): ');
                        if scale(2)>scale(1) break; end
                    end
                elseif plw1==4
                    disp('zmin zmax')
                    disp(scale(3:4))
                    scale(3)=input('Enter top edge (km): ');
                    while 1
                        scale(4)=input('Enter bottom edge (> top edge) (km): ');
                        if scale(4)>scale(3) break; end
                    end
                end
                font_n='tahoma';
                font_s=12;
                close all;
                got=get(0,'screensize');
                figure('position',[170 110 got(3)*0.80 got(4)*0.80],'PaperPositionMode','auto');
                set(gca,'fontname',font_n,'fontsize',font_s)
                clf
                subplot('position',[0.1 0.2 0.8*abs(scale(2)-scale(1))/max_p abs(scale(4)-scale(3))*0.8/max_d*got(3)/got(4)]);
                pcolor(-x,z,b');colormap(cmap);caxis(colim);set(gca,'YDir','reverse');set(gca,'XDir','reverse'); hold on
                plot(NS(stps),zeros(length(stps)),'kv','markerfacecolor','k','markersize',3);
                set(gca,'fontname',font_n,'fontsize',font_s);axis(scale); box on; shading flat;
                set(gca,'DataAspectRatio',[1 1 1]); hold off; pl_ex=1;
                %colorbar and label
                hcb = colorbar('hor','position',[(0.1+0.8*abs(scale(2)-scale(1))/max_p/2-0.125) 0.07 0.25 0.025],...
                    'XTick',[0 0.5,1,1.5,2,2.5,3],...
                    'fontname',font_n,'fontsize',font_s,...
                    'XTickLabel',{'1','3','10','30','100','300','1000'});
                set(get(hcb, 'Title'), 'String', 'Resistivity (\Omegam)','fontsize',12,'fontname',font_n);
                %figure(2);pcolor(-x,z,b');colormap(cmap); caxis(colim);
                %colorbar; set(gca,'YDir','reverse');set(gca,'XDir','reverse'); hold on
                %figure(2);plot(NS(stps),zeros(length(stps)),'kv','markerfacecolor','k','markersize',3);
                %axis equal; shading flat; axis([min(NS(stps))-sttol max(NS(stps))+sttol 0 zax]); box on;
                title([num2str(iks),'. NS-slice']); xlabel('Northing (m)'); ylabel('Depth (km)'); hold off
            elseif plw1==5
                break
            end
        end
    elseif plw==2        %3D slices
        plw3=menu('choose','plot single depth slice','make movie','play movie','done');
        if plw3==1
            close all
            prompt = {'choose slice depths in km(e.g. 50 100 200 ..)'}; titles  = 'Choose slice';
            %it will plot every depth slice you entered and will save them
            %as *.jpg and *.eps
            def = {[num2str(nz)]};
            slcn = str2double(char(inputdlg(prompt,titles,1,def)));
            sEW=EW/111/cos(centlat*pi/180)+centlong;
            sNS=NS/111+centlat;
            mEW=y/111/cos(centlat*pi/180)+centlong;
            mNS=x/111+centlat;
            for pan=1:length(slcn)
                %below allows selection of depth instead of slice number
                dfz=abs(slcn(pan)-z); dfz=find(min(dfz)==dfz); slcn(pan)=dfz;
                a=A(:,:,slcn(pan));
                if centlat>0   %projection map will be generated
                    figure(12);m_proj('lambert','long',[-110.5 -115.2],'lat',[49 52.7256]);%m_gshhs_l('patch',[1 1 1]);
                    m_grid('box','simple','tickdir','in'); hold on
                    m_pcolor(mEW,flipud(mNS),a); m_plot(sEW,sNS,'.k','markersize',14);
                    %axis equal; axis tight;
                    shading flat
                    title(['slice=',num2str(slcn(pan)),'  ==>  ','depth=',num2str(z(slcn(pan))),' km']);
                    colormap(cmap); caxis(colim); %colorbar %xlabel('Easting (km)'); ylabel('Northing (km)');
                else
                    figure(12);pcolor(y,-x,a)
                    hold on; plot(EW,NS,'.k','markersize',12);
                    axis equal; axis tight; shading flat
                    title(['slice=',num2str(slcn(pan)),'  ==>  ','depth=',num2str(z(slcn(pan))),' km']); axis equal; axis tight
                    xlabel('Easting (km)'); ylabel('Northing (km)'); colormap(cmap); caxis(colim);% colorbar
                    plw4=menu('zoom','stations','NO');
                    if plw4==1
                        figure(12); axis([min(EW)-sttol*2 max(EW)+sttol*2 min(NS)-sttol*2 max(NS)+sttol*2]);
                    end
                end
                print(12, '-djpeg80', [num2str(slcn(pan)),'slice',])
                print(12, '-dpsc',[num2str(slcn(pan)),'slice','.eps']);
                if pan<length(slcn) hold off; clf(12); end
            end
        elseif plw3==2
            close all
            for slcn=1:nz+1
                a=A(:,:,slcn);
                pcolor(y,-x,a);
                if slcn==nz+1
                    title(['slice=',num2str(slcn),'  ==>  ','depth=',num2str(z(slcn)),' - halfspace']); axis equal; axis tight
                else
                    title(['slice=',num2str(slcn),'  ==>  ','depth=',num2str(z(slcn)),' - ',num2str(z(slcn+1)),' km']); axis equal; axis tight
                end
                xlabel('Easting (km)'); ylabel('Northing (km)'); colormap(cmap); caxis(colim); colorbar
                hold on; plot(EW,NS,'.k','markersize',12);
                axis equal; axis tight; axis([min(EW)-100 max(EW)+100 min(NS)-100 max(NS)+100]); shading flat
                M1(slcn)=getframe;
            end
        elseif plw3==3
            movie(M1,1,2); movie2avi(M1,'test','quality',100,'fps',2);
        else
            break
        end
    elseif plw==3
            promptw={'select stations to plot'};
            namew='select stations to plot';
            numlinesw=1;
            defaultanswerw={'1:1:20'};
            answerw=inputdlg(promptw,namew,numlinesw,defaultanswerw);
            stp=eval(answerw{1});
    
        if modelmi==2
            load_resp(parfiles,modelmi-1,stp);
            break
        else
            firsts=find(parfile=='_');
            dot1=find(parfile=='.');
            parfile=['out_',parfile(firsts(1)+1:firsts(2)),'resp',parfile(dot1:length(parfile))];
            load_resp(parfile,modelmi-1,stp);
        end
    elseif plw==4
        %%limiting the data matrix%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        close all
        miny=min(EW); maxy=max(EW);  minx=min(NS);  maxx=max(NS);
        minx=find(x>minx-sttol*2 & x<maxx+sttol*2);
        miny=find(y>miny-sttol*2 & y<maxy+sttol*2);
        zaxl=find(z<zax+sttol);
        B=A(minx,miny,zaxl);
        [g h j]=size(B);
        xl=x(minx)'; yl=y(miny)';
        dxx=ones(h,1)*xl; for i=1:j; dxxx(:,:,i)=dxx'; end
        dyy=yl*ones(1,g);for i=1:j; dyyy(:,:,i)=dyy'; end
        dzz=-ones(g,h);
        for i=1:j; dzzz(:,:,i)=dzz*z(i); end

        if length(unique(B))<2; %If you are plotting forward model with slice wiev and your initial model is halfspace
            B(1)=B(1)*1.01; B(2)=B(1)*1.02;   %then slice command of matlab does not work!!!!!
        end                     %Here I modify the B matrix by adding dummy values!!!!! ET, April 2008.

        figure(3);slice(dyyy,-dxxx,dzzz,B,1,1,[0])
        shading flat; colormap(cmap); caxis(colim);
        colorbar; axis equal; axis tight
        hold on; plot3(EW,NS,zeros(1,length(EW)),'kv','markersize',3,'markerfacecolor','k'); box on;
        q=1;
        %%%%%%%%%%%%%%%%%SELECT 3D SLICES%%%%%%%%%%%%%%%%%%%%
        %%this part defines the NS slice locations on EW axis
        while 1
            [iks yes click]=ginput(1);
            if click==3
                break
            end
            ikss=abs(iks-yl);
            ikss=find(ikss==min(ikss));
            sly(q)=yl(ikss);
            q=q+1;
            if q>1
                plot3([sly(q-1) sly(q-1) ],[-xl(g) -xl(g)],[-z(1) -z(j)],'r-','linewidth',3)
                plot3([sly(q-1) sly(q-1) ],[-xl(1) -xl(g)],[-z(1) -z(1)],'r-','linewidth',3)
            end
        end
        nsls=sly;
        %%this part defines the EW slice locations on NS axis
        clear sly ikss
        q=1;
        while 1
            [iks yes click]=ginput(1);
            if click==3
                break
            end
            ikss=abs(yes-xl);
            ikss=find(ikss==min(ikss));
            sly(q)=xl(ikss);
            q=q+1;
            if q>1
                plot3([yl(1) yl(1)],[sly(q-1) sly(q-1) ],[-z(1) -z(j)],'r-','linewidth',3)
                plot3([yl(1) yl(h)],[sly(q-1) sly(q-1) ],[-z(1) -z(1)],'r-','linewidth',3)
            end
        end
        ewls=sly;
        clear sly ikss
        %%this part defines the DEPTH slice locations chosen on any axis
        zsl=inputdlg('depth(1),...,depth(n)','Enter Depth Slices in "km"',1);
        zsl=char(zsl);  zsl=([zsl,',']); zsl1=find(zsl==','); jk=1;
        for iu=1:length(zsl1)
            zsl2(iu,:)=-str2num(zsl(jk:zsl1(iu)-1));
            jk=zsl1(iu)+1;
            ikss=abs(zsl2(iu,:)-(-z));
            ikss=find(ikss==min(ikss));
            sly(iu)=-z(ikss);
            plot3([yl(1) yl(1)],[-xl(1) -xl(g)],[sly(iu) sly(iu)],'-r','linewidth',3)
            plot3([yl(1) yl(h)],[-xl(g) -xl(g)],[sly(iu) sly(iu)],'r-','linewidth',3)
        end
        zls=sly;
        clear sly
        %EW, NS and depth slices are chosen
        figure(4); slice(dyyy,-dxxx,dzzz,B,nsls,ewls,zls);
        shading flat; colormap(cmap); caxis(colim);
        colorbar; axis equal; axis tight
        hold on; plot3(EW,NS,zeros(1,length(EW)),'kv','markersize',3,'markerfacecolor','k'); box on;
    elseif plw==5
        isoA=A;  'isosurface'
        isoA(:,:,1:6)=4;  %1st to 5th layer assigned to be 1000Ohm.m so they wont be plotted
        isoA(:,:,24:31)=4; %we do not want to see the asthenosphere
        miny=min(EW); maxy=max(EW);  minx=min(NS);  maxx=max(NS);
        minx=find(x>minx-sttol*2 & x<maxx+sttol*2);
        miny=find(y>miny-sttol*2 & y<maxy+sttol*2);
        zaxl=find(z<zax+sttol);
        B=isoA(minx,miny,zaxl);
        [g h j]=size(B);
        xl=x(minx)'; yl=y(miny)';
        dxx=ones(h,1)*xl; for i=1:j; dxxx(:,:,i)=dxx'; end
        dyy=yl*ones(1,g);for i=1:j; dyyy(:,:,i)=dyy'; end
        dzz=-ones(g,h);
        for i=1:j; dzzz(:,:,i)=dzz*z(i); end
        figure(46);
        p = patch(isosurface(dyyy,-dxxx,dzzz,B,2.3));
        %isonormals(dyyy,-dxxx,dzzz,B,p);
        isocolors(dyyy,-dxxx,dzzz,B,p);
        %set(p, 'FaceVertexCdata', 1-c)
        set(p, 'FaceColor', 'flat', 'EdgeColor', 'none')
        view(3); daspect([1 1 1]);
        camlight;  camlight(-80,-10); lighting gouraud;
        hold on; plot3(EW,NS,zeros(1,length(EW)),'k.','markersize',12);
        grid on; box on; axis equal; axis tight; axis([-275 275 -230 230 -250 0])
        colormap(cmap); caxis(colim); colorbar
        title('Three dimensional view in meters'); xlabel('Easting (km)'); ylabel('Northing (km)'); zlabel('Depth (km)')
        if centlat>0
            [g h j]=size(B);
            sEW=EW/111/cos(centlat*pi/180)+centlong;
            sNS=NS/111+centlat;
            mEW=yl/111/cos(centlat*pi/180)+centlong;
            mNS=xl/111+centlat;
            dxx=ones(h,1)*mNS; for i=1:j; dxxx(:,:,i)=flipud(dxx'); end
            dyy=mEW*ones(1,g);for i=1:j; dyyy(:,:,i)=dyy'; end
            dzz=-ones(g,h);
            for i=1:j; dzzz(:,:,i)=dzz*z(i); end
            figure(47);%m_proj('lambert','long',[-122.2 -114.8],'lat',[55 59]);%m_gshhs_l('patch',[1 1 1]);
            %m_grid('box','simple','tickdir','in'); hold on
            p = patch(isosurface(dyyy,dxxx,dzzz,B,2.1));
            isocolors(dyyy,(dxxx),dzzz,B,p);
            set(p, 'FaceColor', 'flat', 'EdgeColor', 'none')
            view(3); daspect([1.83 1 111]);
            camlight;  camlight(-80,-10); lighting gouraud;
            hold on; plot3(sEW,sNS,zeros(1,length(EW)),'k.','markersize',12);
            grid on; box on; axis([-123 -114.8 55.1 59.25 -250 0])
            colormap(cmap); caxis(colim); colorbar
            title('Three dimensional view in lat long'); zlabel('Depth (km)') %xlabel('Easting (km)'); ylabel('Northing (km)');
        else
        end
    elseif plw==6
        %EDI... this part will generate edi files from the responses.
        edicor=menu('method','load original mat file for coordinates and site names','only export edis I will change names and coordinates','return');
        %mentioned mat file is generated by load_edi_v*
        %make sure you loaded the correct mat file as you used for
        %generatind the 3D data!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        if edicor==1
            disp('loading reference file')
            [ref_file,ref_path] = uigetfile({'*.mat'},'pick reference mat file');            
            %ref_file=[ref_path,'/',ref_file];
            eval(['load ',ref_file]);
            clear ZZZ ZZZ_HZ EEE EEE_HZ T
            resfile=parfile;
            fghk=find(resfile=='.'); resfile(fghk-4:fghk-1)='resp';resfile(13)=[];
            fidr=fopen(resfile,'r');
            par_r=fscanf(fidr,'%d',3);
            ns_r=par_r(1); np_r=par_r(2); nr_r=par_r(3);
            durp=0; % this loop finds the header lines count in the response file.
            fgetl(fidr);
            if ns~= length(site)
                warndlg('number of sites in *.mat file does not match the number of sites in resp file!!! ');
            else
                while 1
                    durp=durp+1;
                    dur_bak=fgetl(fidr);
                    if dur_bak(1:1)=='D'
                        durp=durp+1;
                        break
                    end
                end
                atla=0;         % read impedances
                for pust=1:np_r
                    [zxxr(:,pust) zxxi(:,pust) zxyr(:,pust) zxyi(:,pust) zyxr(:,pust) zyxi(:,pust) zyyr(:,pust) zyyi(:,pust)]=textread(resfile,'%f%f%f%f%f%f%f%f',ns_r,'headerlines',durp+atla);
                    atla=atla+ns_r+1;  %rows to skip at every reading step
                end
                zxxr=796*zxxr;  zxxi=-796*zxxi;  zxyr=796*zxyr;  zxyi=-796*zxyi;  zyxr=796*zyxr;  zyxi=-796*zyxi;  zyyr=796*zyyr;  zyyi=-796*zyyi; %converting the unit and taking the conjugate again
                fclose(fidr); fidr=fopen(resfile,'r');
                % read periods
                per_count=1;
                while 1
                    qwe=fgetl(fidr);
                    if qwe(1)=='#';
                        break
                    elseif qwe(1)=='D'
                        per_r(:,per_count)=str2num(qwe(13:length(qwe)));
                        per_count=per_count+1;
                    end
                end
                fclose(fidr);
                s_promptg = {'Enter coordinate frame rotation pozitive from north to east'};
                s_titlesg  = 'Choose limits';
                s_defg= {'0'};
                zrot_ang = char(inputdlg(s_promptg,s_titlesg,1,s_defg));

                for stw=1:length(site)
                    fid=fopen([site{stw},'.edi'],'r');
                    fid2=fopen([site{stw},'resp.edi'],'w');
                    %This loop writes the header lines in the edi
                    while 1
                        Li=fgetl(fid);
                        if length(Li)>6 & Li(1:5)=='>FREQ'
                            Li=['>FREQ NFREQ=',num2str(np_r),' ORDER=DEC // ',num2str(np_r)];
                            fprintf(fid2,'%s\n',Li);
                            fclose(fid); %close the edi file
                            break   %header is done!
                        elseif length(Li)>6 & Li(1:3)=='Dec'
                            Li='Declination=0';
                            fprintf(fid2,'%s\n',Li);   %prints the header information
                        elseif length(Li)>6 & Li(1:6)=='NFREQ='
                            Li=['NFREQ=',num2str(np_r)];
                            fprintf(fid2,'%s\n',Li);   %prints the header information
                        elseif length(Li)>6 & Li(1:3)=='Rot'
                            Li='Rotated from measurement coordinate system by: 0 degrees';
                            fprintf(fid2,'%s\n',Li);   %prints the header information
                        elseif length(Li)>2 & Li(1:3)=='HZ='
                            %do nothing
                        else
                            fprintf(fid2,'%s\n',Li);   %prints the header information
                        end
                    end
                    %print the impedance and error

                    if str2num(zrot_ang)==0
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',1./per_r); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZXXR ROT=NORTH // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zxxr(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZXXI ROT=NORTH // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zxxi(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZXX.VAR ROT=NORTH // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zeros(1,np_r)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZXYR ROT=NORTH // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zxyr(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZXYI ROT=NORTH // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zxyi(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZXY.VAR ROT=NORTH // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zeros(1,np_r)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZYXR ROT=NORTH // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zyxr(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZYXI ROT=NORTH // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zyxi(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZYX.VAR ROT=NORTH // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zeros(1,np_r)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZYYR ROT=NORTH // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zyyr(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZYYI ROT=NORTH // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zyyi(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZYY.VAR ROT=NORTH // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zeros(1,np_r)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n','>END');
                        fclose(fid2);
                    else
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',1./per_r); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n','>!****IMPEDANCE ROTATION ANGLES****!'); %fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZROT //',num2str(np_r)]);
                        sdtp=(ones(1,np_r).*str2num(zrot_ang));
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',sdtp); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZXXR ROT=ZROT // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zxxr(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZXXI ROT=ZROT // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zxxi(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZXX.VAR ROT=ZROT // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zeros(1,np_r)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZXYR ROT=ZROT // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zxyr(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZXYI ROT=ZROT // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zxyi(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZXY.VAR ROT=ZROT // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zeros(1,np_r)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZYXR ROT=ZROT // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zyxr(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZYXI ROT=ZROT // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zyxi(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZYX.VAR ROT=ZROT // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zeros(1,np_r)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZYYR ROT=ZROT // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zyyr(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZYYI ROT=ZROT // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zyyi(stw,:)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n',['>ZYY.VAR ROT=ZROT // ',num2str(np_r)]);
                        fprintf(fid2,'%1.5E  %1.5E  %1.5E  %1.5E  %1.5E\n',zeros(1,np_r)); fprintf(fid2,'\n');
                        fprintf(fid2,'%s\n','>END');
                        fclose(fid2);
                    end
                end
            end
        elseif edicor==2
            warndlg('NOT implemented YET!!! ');
            %not implemented yet.
        else
            break
            return
        end
    elseif plw==7
        %export the model in winglink format.
        winglink(parfile,x,y,z,nx,ny,nz,OA) %writes 'parfile'.out for winglink 3D forward
    else
        break
        return
    end
end






%==================FUNCTIONS%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%==================Generates *.out file to import winglink 3D==========
function winglink(parfile,x,y,z,nx,ny,nz,OA)
%Generates *.out file for winglink
global colim
fid=fopen([parfile,'.out'],'w');
fprintf(fid,'%3d %3d %3d %3d %s\n',ny,nx,nz,7,'VALUES');
fprintf(fid,'%d\n',diff(y)*1000);
fprintf(fid,'%d\n',diff(x)*1000);
fprintf(fid,'%d\n',diff(z)*1000);
%sil=reshape(A,nx,ny,nz);
for i=1:nz
    fprintf(fid,'%s\n',num2str(i));
    fprintf(fid,'%7.3f %7.3f\n',OA(:,:,i)');
end
fprintf(fid,'%s\n','WINGLINK');
fprintf(fid,'%s\n','  Site_not_set  (site name)');
fprintf(fid,'%s\n','             1             1  (i j block numbers)');
%These coordinates have to be coorect otherwise stations would not be on the mesh

prompt = {'Enter real world coordinates as appear in *.out winglink model (1.):','Enter real world coordinates as appear in *.out winglink model (2.):','Enter mesh rotation (positive NW):'};
dlg_title = 'Read these numbers from *.out winglink exported original model';
num_lines = 1;
def = {'-627.69','1219.80','45'};
answer = inputdlg(prompt,dlg_title,num_lines,def);
coord=['  ',answer{1},'   ',answer{2},'  (real world coordinates)'];
rota_syon=['             ',answer{3},'  (rotation)'];
fprintf(fid,'%s\n',coord);
fprintf(fid,'%s\n',rota_syon);
fprintf(fid,'%s\n','             0  (top elevation)');
fclose(fid);

%==================loads initial model for data plotting===============
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [NS,EW]=load_init(name);
%1.5Ersan Turkoglu, March 2006
%This function reads the data
global A ns np nr snameg RMS
fid=fopen(name,'r');x1=fscanf(fid,'%f');
snameg=name;
ns=x1(1); np=x1(2); nr=x1(3);
x2=fgetl(fid);
NS=fscanf(fid,'%f\n',ns)/1000;
x3=fgetl(fid);
EW=fscanf(fid,'%f',ns)/1000;

function [niter,RMS,nx,ny,nz,x,y,z,A,NS,EW,ns,nr,np]=load_para(name);
%this function reads the model file
global OA A ns np nr snameg RMS
fid=fopen(name,'r');
line1=fgetl(fid);
niter=eval(line1(18))-1;  %it shows one more than actual...why?
RMS=eval(line1(33:38));

line2=fgetl(fid);
nx=eval(line2(3:4));       %number of blocks in NS
ny=eval(line2(7:8));       %number of y blocks in EW
nz=eval(line2(11:12));     %number of z slices
un=eval(line2(16));        %I don't remember this parameter ????????????

xxx=fscanf(fid,'%f',nx+ny+nz);  %block size
x=xxx(1:nx);x=cumsum(x);x=[0;x];
x=[x(1:nx/2)-x(nx/2+1);0;x(nx/2+2:nx+1)-x(nx/2+1)]/1000;
y=xxx(nx+1:nx+ny);
y=cumsum(y);y=[0;y]';
y=[y(1:ny/2)-y(ny/2+1),0,y(ny/2+2:ny+1)-y(ny/2+1)]/1000;
z=xxx(nx+ny+1:nx+ny+nz); z=cumsum(z);z=[0;z]/1000;
A=reshape(fscanf(fid,'%f'),nx,ny,nz);      %z is the depth slices
OA=A;
A(nx+1,:,:)=A(nx,:,:);          %these arrangements are needed for pcolor plotting
A(:,ny+1,:)=A(:,ny,:);
A(:,:,nz+1)=A(:,:,nz);
A=log10(A);
fclose(fid);
%------------------Reads the station info--------------
first=find(name=='_');
sname=name(first(1)+1:first(2)-1);
sname=[sname,'.data'];
sname
fid=fopen(sname,'r');
x1=fscanf(fid,'%f');
snameg=sname;
ns=x1(1); np=x1(2); nr=x1(3);
x2=fgetl(fid);
NS=fscanf(fid,'%f\n',ns)/1000;
x3=fgetl(fid);
%x3=fgetl(fid); %some matlabs needs this line
EW=fscanf(fid,'%f',ns)/1000;
%====================================================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function load_resp(name,modelmi,stp)
%1.5Ersan Turkoglu, March 2006
%This function reads the response file and plots the response
global colim
global ns np nr snameg RMS site sites cmap
if modelmi==1
    lapa=3;
    ls=2;
else
    lapa=4;
    ls=1;
end
for io=1:ls:lapa
    clear namec flag
    if io==1
        namec=snameg;
        flag=1;
        title1='TM Observation';
        clear xxx fid x y s z Z T stz zxx zxy zyy zyx rhoxx rhoxy rhoyx rhoyy TT tt yys dyy plda iy
    elseif io==2
        flag=0;
        namec=name;
        title2='TM Response';
        clear xxx fid x y s z Z T stz zxx zxy zyy zyx rhoxx rhoxy rhoyx rhoyy TT tt yys dyy plda iy
    elseif io==3
        namec=snameg;
        flag=1;
        title3='TE Observation';
        clear xxx fid x y s z Z T stz zxx zxy zyy zyx rhoxx rhoxy rhoyx rhoyy TT tt yys dyy plda iy
    elseif io==4
        flag=0;
        namec=name;
        title4='TE Response';
        clear xxx fid x y s z Z T stz zxx zxy zyy zyx rhoxx rhoxy rhoyx rhoyy TT tt yys dyy plda iy
    end
    fid=fopen(namec,'r');
    xxx=fscanf(fid,'%f',3);ns=xxx(1); nf=xxx(2); nr=xxx(3);
    s=fscanf(fid,'%s',2); x=fscanf(fid,'%f',ns);  %NORTHING !!!!!!!!!
    s=fscanf(fid,'%s',2); y=fscanf(fid,'%f',ns);  %1.5EASTING !!!!!!!!!
    s=fscanf(fid,'%s',1); T(1)=fscanf(fid,'%f',1);
    Z(:,:,1)=reshape(fscanf(fid,'%f',nr*ns),nr,ns)';
    for ii=2:nf
        s=fscanf(fid,'%s',1); T(ii)=fscanf(fid,'%f',1);
        Z(:,:,ii)=reshape(fscanf(fid,'%f',nr*ns),nr,ns)';
    end
    if flag==1
        s=fscanf(fid,'%s',1); T(1)=fscanf(fid,'%f',1);
        Zerr(:,:,1)=reshape(fscanf(fid,'%f',nr*ns),nr,ns)';
        for ii=2:nf
            s=fscanf(fid,'%s',1); T(ii)=fscanf(fid,'%f',1);
            Zerr(:,:,ii)=reshape(fscanf(fid,'%f',nr*ns),nr,ns)';
        end
    end

    if flag==1
        s=fscanf(fid,'%s',1); T(1)=fscanf(fid,'%f',1);
        ZerrMap(:,:,1)=reshape(fscanf(fid,'%f',nr*ns),nr,ns)';
        for ii=2:nf
            s=fscanf(fid,'%s',1); T(ii)=fscanf(fid,'%f',1);
            ZerrMap(:,:,ii)=reshape(fscanf(fid,'%f',nr*ns),nr,ns)';
        end
    end

    Zerr=Zerr.*ZerrMap;

    for ik=1:ns          %ns
        for il=1:nr
            stz(:,il)=Z(ik,il,:);          %Z is nsXnrXnp
            if flag==1
                stzerr(:,il)=Zerr(ik,il,:);          %Zerr is nsXnrXnp
            end
        end
        if nr==8
            zxx(:,ik)=stz(:,1)+(i*stz(:,2));
            zxy(:,ik)=stz(:,3)+(i*stz(:,4));
            zyx(:,ik)=stz(:,5)+(i*stz(:,6));
            zyy(:,ik)=stz(:,7)+(i*stz(:,8));
            rhoxx(:,ik)=1*T'/2/pi/4/pi/10^-7.*(zxx(:,ik).*conj(zxx(:,ik)));
            rhoxy(:,ik)=1*T'/2/pi/4/pi/10^-7.*(zxy(:,ik).*conj(zxy(:,ik)));
            rhoyx(:,ik)=1*T'/2/pi/4/pi/10^-7.*(zyx(:,ik).*conj(zyx(:,ik)));
            rhoyy(:,ik)=1*T'/2/pi/4/pi/10^-7.*(zyy(:,ik).*conj(zyy(:,ik)));
        else
            zxy(:,ik)=stz(:,1)+(i*stz(:,2));
            zyx(:,ik)=stz(:,3)+(i*stz(:,4));
            rhoxy(:,ik)=1*T'/2/pi/4/pi/10^-7.*(zxy(:,ik).*conj(zxy(:,ik)));
            rhoyx(:,ik)=1*T'/2/pi/4/pi/10^-7.*(zyx(:,ik).*conj(zyx(:,ik)));
        end

        if flag==1
            if nr==8
                erxx=(stzerr(:,1)); %standard deviation of zz
                erxx=erxx./sqrt(zxx(:,ik).*conj(zxx(:,ik))); %Convert error to percentage
                rhoxxerr(:,ik)=rhoxx(:,ik).*(2*(erxx)+(erxx).^2);

                erxy=(stzerr(:,3)); %standard deviation of zz
                erxy=erxy./sqrt(zxy(:,ik).*conj(zxy(:,ik)));
                rhoxyerr(:,ik)=rhoxy(:,ik).*(2*(erxy)+(erxy).^2);


                eryx=(stzerr(:,5)); %standard deviation of zz
                eryx=eryx./sqrt(zyx(:,ik).*conj(zyx(:,ik)));
                rhoyxerr(:,ik)=rhoyx(:,ik).*(2*(eryx)+(eryx).^2);


                eryy=(stzerr(:,7)); %standard deviation of zz
                eryy=eryy./sqrt(zyy(:,ik).*conj(zyy(:,ik)));
                rhoyyerr(:,ik)=rhoyy(:,ik).*(2*(eryy)+(eryy).^2);

            else
                erxy=(stzerr(:,3)); %standard deviation of zz
                erxy=erxy./sqrt(zxy(:,ik).*conj(zxy(:,ik)));
                rhoxyerr(:,ik)=rhoxy(:,ik).*(2*(erxy)+(erxy).^2);

                eryx=(stzerr(:,5)); %standard deviation of zz
                eryx=eryx./sqrt(zyx(:,ik).*conj(zyx(:,ik)));
                rhoyxerr(:,ik)=rhoyx(:,ik).*(2*(eryx)+(eryx).^2);
            end
        end
    end
    %     rhoxy(:,ik)
    %     rhoxyerr(:,ik)
    %     erxy
    %     errorbar(log10(T),rhoxy(:,ik),rhoxyerr(:,ik),'ks','markersize',3); hold on;% axis([-0.8 4.2 -0.5 3]);
    %             set(gca, 'YScale', 'log');
    %             pause
    %

    if nr==8
        rhoxx(nf+1,:)=rhoxx(nf,:);rhoxy(nf+1,:)=rhoxy(nf,:);rhoyx(nf+1,:)=rhoyx(nf,:);rhoyy(nf+1,:)=rhoyy(nf,:);
        rhoxx(:,ik+1)=rhoxx(:,ik);rhoxy(:,ik+1)=rhoxy(:,ik);rhoyx(:,ik+1)=rhoyx(:,ik);rhoyy(:,ik+1)=rhoyy(:,ik);
    else
        rhoxy(nf+1,:)=rhoxy(nf,:);rhoyx(nf+1,:)=rhoyx(nf,:);
        rhoxy(:,ik+1)=rhoxy(:,ik);rhoyx(:,ik+1)=rhoyx(:,ik);
    end
    TT=log10(T);
    dt=diff(TT);  tt(1)=TT(1)-dt(1)/2; tt(2:nf)=TT(1:nf-1)+dt/2;  tt(nf+1)=TT(nf)+dt(nf-1)/2; TT=tt;
    %[x ix]=sort(x);
    %ATTENTION
    ix=1:length(x);
    if nr==8
        rhoxx=[rhoxx(:,[ix]),ones(nf+1,1)]; rhoxy=[rhoxy(:,[ix]),ones(nf+1,1)]; rhoyx=[rhoyx(:,[ix]),ones(nf+1,1)]; rhoyy=[rhoyy(:,[ix]),ones(nf+1,1)];
        rhoxxerr=rhoxxerr(:,ix);
        rhoxyerr=rhoxyerr(:,ix);
        rhoyxerr=rhoyxerr(:,ix);
        rhoyyerr=rhoyyerr(:,ix);
    else
        rhoxy=[rhoxy(:,[ix]),ones(nf+1,1)]; rhoyx=[rhoyx(:,[ix]),ones(nf+1,1)];
        rhoxyerr=rhoxyerr(:,ix);rhoyxerr=rhoyxerr(:,ix);
    end
    dx=diff(x); xx(1)=x(1)-dx(1)/2;    xx(2:ns)=x(1:ns-1)+dx/2;  xx(ns+1)=x(ns)+dx(ns-1)/2; dxx=diff(xx);
    if io==1
        plda=rhoxx;
        save xyzZxxob.mat x y TT plda
        plda=rhoyy;
        save xyzZyyob.mat x y TT plda
    elseif io==2
        plda=rhoxx;
        save xyzZxxresp.mat x y TT plda
        plda=rhoyy;
        save xyzZyyresp.mat x y TT plda
    end 

    if io<3  %io=1 means Zyx observed, io=2 is Zyx resp., io=3 is Zxy observed, io=4 is Zxy resp.
        plda=rhoyx;
        if io==1
            save xyzZyxob.mat x y TT plda
        else
            save xyzZyxresp.mat x y TT plda
        end

        if flag==1
            pldaerr=rhoyxerr;
        end
    else
        plda=rhoxy;
        if io==3
            save xyzZxyob.mat x y TT plda
        else
            save xyzZxyresp.mat x y TT plda
        end
        if flag==1
            pldaerr=rhoxyerr;
        end
    end
    %%%%%%%%%Below plots all the stations on one profile%%%%%%%%%%%%%%%%%%%%
    %figure(1);subplot(4,1,io);pcolor(xx/1000,TT',log10(plda));
    %set(gca,'YDir','reverse');; colormap(flipud(cmap)); caxis(colim); colorbar;
    %tit=eval(['title',num2str(io)]);
    %title([tit]); xlabel('Distance (km)');ylabel('Log10(per) (sec)');
    %xxs=xx(1:ns)+dxx/2;
    %hold on; plot(xxs/1000,ones(length(xxs))*TT(1),'kv');
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    tdn=ceil(sqrt(length(stp)));
    if io==1
        for ip=1:length(stp)
            figure(2);subplot(tdn,tdn,ip);
            errorbarloglog(T,(plda(1:np,stp(ip))),(pldaerr(1:np,stp(ip))),'none','v',3,'k'); hold on; box on;% axis([-0.8 4.2 -0.5 3]);
            axis([T(1)-T(1)/2 T(length(T))+T(length(T))/2 1 100000]);
            set(gca,'YTick',[10 1000 100000]); set(gca,'XTick',[1 10 100 1000 10000]);
            set(gca,'YTickLabel',{'1';'3';'5'}); set(gca,'XTickLabel',{'0';'1';'2';'3';'4'});
            [T';plda(1:np,1)]; title(num2str(stp(ip)));
            %xlabel('Period (s)'); ylabel('Apparent Resistivity (\Omegam)')
        end
    elseif io==2
        for ip=1:length(stp)
            figure(2);subplot(tdn,tdn,ip);plot(T,(plda(1:np,stp(ip))),'k--');
            hold on; axis([T(1)-T(1)/2 T(length(T))+T(length(T))/2 1 100000]); title(['Ryx',' station number= ',num2str(stp(ip))]);
            set(gca,'YTick',[10 1000 100000]); set(gca,'XTick',[1 10 100 1000 10000]);
            set(gca,'YTickLabel',{'1';'3';'5'}); set(gca,'XTickLabel',{'0';'1';'2';'3';'4'});
        end
    end
    if io==3
        for ip=1:length(stp)
            figure(2);subplot(tdn,tdn,ip);errorbarloglog(T,(plda(1:np,stp(ip))),(pldaerr(1:np,stp(ip))),'none','o',3,'k'); hold on; box on;% axis([-0.8 4.2 -0.5 3]);
            axis([T(1)-T(1)/2 T(length(T))+T(length(T))/2 1 100000]);
            set(gca,'YTick',[10 1000 100000]); set(gca,'XTick',[1 10 100 1000 10000]);
            set(gca,'YTickLabel',{'1';'3';'5'}); set(gca,'XTickLabel',{'0';'1';'2';'3';'4'});
        end
    elseif io==4
        for ip=1:length(stp)
            figure(2);subplot(tdn,tdn,ip);plot(T,(plda(1:np,stp(ip))),'k-');
            hold on; axis([T(1)-T(1)/2 T(length(T))+T(length(T))/2 1 100000]); title(['Rxy',' station number= ',num2str(stp(ip))]);
            set(gca,'YTick',[10 1000 100000]); set(gca,'XTick',[1 10 100 1000 10000]);
            set(gca,'YTickLabel',{'1';'3';'5'}); set(gca,'XTickLabel',{'0';'1';'2';'3';'4'});
            %xlabel('Period (s)'); ylabel('Apparent Resistivity (\Omegam)')
        end
    end
    fclose(fid);
end
%plots pcolor section of response and observed data as pcolor
if modelmi~=1
    modelmi;
    pcol_resp
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function pcol_resp
%1.5Ersan Turkoglu, 8 July 2007
%This program plots pseudo sections for selected profiles
global sttol cmap colim pref_strike
partimp=menu('What part of the impedance for pseude section plot?','Plot diagonals(Zxx&Zyy)','Plot off diagonals(Zxy&Zyx)');
for po=1:4
    if po==1 
        if partimp==2 
            load xyzZxyob.mat;
        elseif partimp==1
            load xyzZxxob.mat;
        end
    elseif po==2 
        if partimp==2
            load xyzZxyresp.mat
        elseif partimp==1
            load xyzZxxresp.mat
        end
    elseif po==3
        if partimp==2 
            load xyzZyxob.mat;
        elseif partimp==1
            load xyzZyyob.mat;
        end
    elseif po==4
        if partimp==2 
            load xyzZyxresp.mat;
        elseif partimp==1
            load xyzZyyresp.mat;
        end
    end
    %redefine coordinates x means east in this program
    if po==1 %this statement will run only once as it should be same for all...
        yY=y; y=x/1000; x=yY/1000;
        figure(720);plot(x,y,'.b','markersize',16); hold on; title('choose stations to plot response');
        stps=[];
        plw=menu('choose','NS section','EW section');
        if plw==1
            %North-South
            figure(720);[exs yes click]=ginput(1);
            ye=abs(exs-(x));
            lye=length(ye);
            ye=find(ye==min(ye));
            stps=find(x>x(ye)-sttol/2 & x<x(ye)+sttol/2)';
            figure(720);plot(x(stps),y(stps),'.r','markersize',16);
            figure(720); plot([x(ye)-sttol/2,x(ye)-sttol/2],[min(y) max(y)],'r-','linewidth',2);  %draw a line for selected profile
            figure(720); plot([x(ye)+sttol/2,x(ye)+sttol/2],[min(y) max(y)],'r-','linewidth',2);  %draw a line for selected profile
        elseif plw==2
            %1.5East-West
            figure(720);[exs yes click]=ginput(1);
            ye=abs(yes-(y));
            lye=length(ye);
            ye=find(ye==min(ye));
            stps=find(y>y(ye)-sttol/2 & y<y(ye)+sttol/2)';
            figure(720);plot(x(stps),y(stps),'.r','markersize',16);
            figure(720); plot([min(x) max(x)],[y(ye)-sttol/2,y(ye)-sttol/2],'r-','linewidth',2);  %draw a line for selected profile
            figure(720); plot([min(x) max(x)],[y(ye)+sttol/2,y(ye)+sttol/2],'r-','linewidth',2); %draw a line for selected profile
        end

        while 1
            figure(720);[exs yes click]=ginput(1);

            if click==3; break; end
            stp1=find(y>yes-sttol/6 & y<yes+sttol/6 & x>exs-sttol/6 & x<exs+sttol/6);
            if stp1>0
                dec=find(stps==stp1);
                if dec>0
                    stps(dec)=[];
                else
                    stps=[stps,stp1];
                end
                plot(x,y,'.b','markersize',16); plot(x(stps),y(stps),'.r','markersize',16)
            end
        end
        if plw==1 %Nort south
            ys=y(stps);
            rs=ys;
            ds=rs;
        elseif plw==2 %1.5East west
            xs=x(stps);
            rs=xs;
            ds=rs;
        end
    end
    %After this point plda will be different for each po loop
    plda=log10(plda(:,stps)); plda=plda'; ty=size(plda);
    % %figure(72);plot(x,ones(1,length(x)),'kv')
    %reorder stations monotonically for pcolor
    plda(:,ty(2)+1)=ds;
    plda=sortrows(plda,ty(2)+1);
    rs=plda(:,ty(2)+1);
    plda(:,ty(2)+1)=[];
    plda=plda';
    nsites=ty(1);
    rs=rs+abs(min(rs));
    dx=diff(rs);
    T=diff(TT);
    % shift everything half dx to the left/right
    yy(1)=rs(1)-dx(1)/2;
    yy(2:nsites)=rs(1:nsites-1)+dx/2;
    yy(nsites+1)=rs(nsites)+dx(nsites-1)/2;
    xx=yy;
    tt(1)=TT(1)-T(1)/2;
    tt(2:length(TT))=TT(1:length(TT)-1)+T/2;
    tt(length(TT)+1)=TT(length(TT))+T(length(TT)-1)/2;
    TTT=tt;
    % extend arrays for pcolor
    plda(ty(2)+1,:)=plda(ty(2),:);
    plda(:,ty(1)+1)=plda(:,ty(1));

    figure(28); subplot(2,2,po); pcolor(xx,TTT',plda); hold on
    plot(rs,ones(1,length(rs))*TTT(1)+0.0001,'kv','markerfacecolor','k','markersize',3); shading flat
    set(gca,'YDir','reverse');set(gca,'XDir','reverse');
    if plw==1 set(gca,'XDir','reverse'); end
    colormap(cmap); caxis(colim); colorbar
    if po==1 && partimp==2
        title('Zxy observed'); 
    elseif po==2 && partimp==2 
        title('Zxy response'); 
    elseif po==3 && partimp==2 
        title('Zyx observed'); 
    elseif po==4 && partimp==2
        title('Zyx response');
    end
    if po==1 && partimp==1 
        title('Zxx observed'); 
    elseif po==2 && partimp==1 
        title('Zxx response'); 
    elseif po==3 && partimp==1 
        title('Zyy observed'); 
    elseif po==4 && partimp==1
        title('Zyy response'); 
    end
end
