%=======================================================================
function load_edis
%=======================================================================
% ET, December 2007==>load_edis_v3 a treshold applied to mask noisy points.
% Program will look at the difference of a point from both sides (in log domain). 
% If difference on both sides larger than the treshold, then this point will be
% masked. Each component as well as MAG and IMPED. are dealed independently.
% ET, February 2007==>load_edis_v2 gives option to load differently sampled
% periods in edi files. Good to load MTU and NIMS data together. The
% program resamples the data by 1-D interpolation (be carefull if your data is noisy).
% ET, October 2006 ==>small modifications to make this program stand alone
% No need to have a station list file
% non edi files are succesfully disregarded
% ws, april '04
% loads a series of edi files and saves its contents in a mat file.
%=======================================================================
% settings
warning off;
TT=logspace(-4, 5, 72);  %IMPORTANT equally sampled periods
treshold=0.20 %treshold level to mask noisy data
%%%%%%%%%%%%%%Optional%%%%%%%%%%%%%%%%%%%%%
%acts=cd;   %current directory
% dirn = uigetdir('C:\Ersan/data_production','Pick *.edi directory');
% if dirn==0; return; end
% eval(['cd ',dirn]);
%%%%%%%%%%%%%Optional End%%%%%%%%%%%%%%%%%%%%%%
edst=ls; [fff iio]=size(edst);  edst=edst(3:fff,:); [fff iio]=size(edst);
ff=0;
for iio=1:fff
    fgd=find(edst(iio,:)=='.')+1;
    if fgd>1
        edst(iio,fgd:fgd+1);
        if edst(iio,fgd:fgd+1)=='ed'
            ff=ff+1;
            finst(ff,:)=edst(iio,:);
        else
            disp([edst(iio,:),' is not an edi file']);
        end
    end
end
edst=finst;
coord = []; pers = [];  [nsta fff]=size(edst);
% start loop over sites
for iyu=1:nsta
    % read edi file
    [head,info,definemeas,mtsect,dat] = read_edi(edst(iyu,:));
    % azimuth = negative declination
    theta_el    = -dat.azim;
    theta_mag   = -dat.azim;           %This is the case only for abt data set
    coordinates = dat.coord(1:2)';
    ntp         = length(dat.freq);
    period      = 1./dat.freq;
    % rotate impedances to geographic north
    [z,dz] = rot_z_edi(dat.z,dat.dz,theta_el,theta_mag);
    % same for geomagnetic transfer function
    [z_hz,dz_hz] = rot_hz_edi(dat.z_hz,dat.dz_hz,theta_mag);
    for ic=1:4
        %%%%%%%%Treshold%%%%%%%%%%
        zeze=z(ic,:);deze=dz(ic,:); astk=1; astir=0; periods=period;
        for tre=2:ntp-1
            if abs(abs(log10(abs(z(ic,tre))))-abs(log10(abs(z(ic,tre-1)))))>treshold & abs(abs(log10(abs(z(ic,tre+1))))-abs(log10(abs(z(ic,tre)))))>treshold
                astir(astk)=tre;
                astk=astk+1;
            end
        end
        if astir(1)>1
            zeze(astir)=[]; deze(astir)=[]; periods(astir)=[];
        end
        ZZint(ic,:)=10.^interp1(log10(periods),log10(zeze),log10(TT),'linear');
        EEint(ic,:)=10.^interp1(log10(periods),log10(deze),log10(TT),'linear');
        if ic<3
            %%%%%%%%Treshold%%%%%%%%%%
            zeze=z_hz(ic,:);deze=dz_hz(ic,:); astk=1; astir=0; periods=period;
            for tre=2:ntp-1
                if abs(abs(log10(abs(z_hz(ic,tre))))-abs(log10(abs(z_hz(ic,tre-1)))))>treshold & abs(abs(log10(abs(z_hz(ic,tre+1))))-abs(log10(abs(z_hz(ic,tre)))))>treshold
                    astir(astk)=tre;
                    astk=astk+1;
                end
            end
            if astir(1)>1
                zeze(astir)=[]; deze(astir)=[]; periods(astir)=[];
            end
            ZZint_hz(ic,:)=10.^interp1(log10(periods),log10(zeze),log10(TT),'linear');
            EEint_hz(ic,:)=10.^interp1(log10(periods),log10(deze),log10(TT),'linear');
        end
    end
    subplot(211);loglog(period,abs(z_hz(2,:)),'o');hold on; loglog(TT,abs(ZZint_hz(2,:)),'*');legend('original','interpolated'); 
    title('MAG.'); xlabel('Period (sec.)'); ylabel('ABS(Tzy)');
    subplot(212);loglog(period,abs(z(2,:)),'o');hold on; loglog(TT,abs(ZZint(2,:)),'*');legend('original','interpolated'); 
    title('IMPED.'); xlabel('Period (sec.)'); ylabel('ABS(Zxy)');
    z=ZZint; dz=EEint;
    pers=[pers period];
    z_hz=ZZint_hz;
    dz_hz=EEint_hz;
    ZZZ(:,:,iyu)=z;
    EEE(:,:,iyu)=dz;
    ZZZ_HZ(:,:,iyu)=z_hz;
    EEE_HZ(:,:,iyu)=dz_hz;
    coord = cat(2,coord,coordinates);
    [pathstr,name,ext,versn] = fileparts(edst(iyu,:));
    site{iyu} = name;
end
T = TT'; coord = [coord(2,:);coord(1,:)]';
eval(['save ',edst(1,1:3),' ZZZ EEE ZZZ_HZ EEE_HZ T coord site']);
%%%%%%%%%%%%%%%%%%%%%END load_edis%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%=======================================================================
function [z,dz]=rot_z_edi(z,dz,theta_el,theta_mag)
%=======================================================================
% rotates impedances w/ errors as found in edi file
% theta is in degrees (positive is clockwise)

c = cos(theta_el*pi/180.);
s = sin(theta_el*pi/180.);
%cm = cos(theta_mag*pi/180.);
%sm = sin(theta_mag*pi/180.);
U = [ c*c ,  c*s ,  c*s , s*s  ;...
    -c*s ,  c*c , -s*s , c*s  ;...
    -c*s , -s*s ,  c*c , c*s  ;...
    s*s , -c*s , -c*s , c*c ];
z = U*z;
dz = (U.^2*dz.^2).^.5;
%dz = abs(U*dz);
%================================================================
function [z_hz,dz_hz] = rot_hz_edi(z_hz,dz_hz,theta_mag)
%================================================================
% rotates local magnetic transfer functions (induction vectors)
% as found in edi file
% theta in degrees (positive is clockwise)
c = cos(theta_mag*pi/180.);
s = sin(theta_mag*pi/180.);
Uv = [ c  , s ;...
    -s  , c ];
z_hz = Uv*z_hz;
dz_hz = (Uv.^2*dz_hz.^2).^.5;