%==========================================================================
%
function [head,info,definemeas,mtsect,dat] = read_edi(file)
%
%Program can load winglink edis properly
%ET, January 2007
%==========================================================================
% this is a first start to get edi files read into matlab
% - just a few realizations of the 'standard' will be readable!
%
% section: '>='
% key:     '>'
% param:   '='
%
% get_key/section   : store lines of key/section in variable
% read_section      : read these lines (section) into two structs
% read_mtsect (e.g.): read these structs
% 
% ws, april '04
%
%==========================================================================

if exist(file,'file')
    fid=fopen(file,'r');
    disp(['File ',file,' opened']);
else
    error(['File ',file,' not found!']);
    return
end

%============================================
head = get_key(fid,0,'HEAD');
%============================================
%info = get_key(fid,0,'INFO');
info='not implemented';
%============================================
definemeas = get_section(fid,'DEFINEMEAS');
[param,key] = read_section(fid,definemeas);
[coord] = read_definemeas(param,key);
%============================================
mtsect = get_section(fid,'MTSECT');
[param,key] = read_section(fid,mtsect);
[freq,azim,z,dz,z_hz,dz_hz] = read_mtsect(param,key);
%============================================

dat = struct(...
    'freq',freq,'azim',azim,'coord',coord,'z',z,'dz',dz,...
    'z_hz',z_hz,'dz_hz',dz_hz);
fclose(fid);
return


%============================================
function coord = read_definemeas(param,key)
%============================================
par = {'UNITS','REFLAT','REFLONG','REFELEV'};

for ipar=1:length(param)
    for kpar=1:length(par)
        if strmatch(param(ipar).name,char(par(kpar)))
            parval{kpar}=param(ipar).value;
        end
    end
end

units=char(parval{1});
if units(1:1)~='M'
    warning(['units are non-metric: units=',units]);
end

lat=parval{2}; lon=parval{3}; ele=str2num(parval{4});
if ~isempty(lat) & ~isempty(lon)
    [dms]=sscanf(lat,'%d:%d:%d');
    rest=(dms(2)+dms(3)/60)/60;
    if dms(1)<0 lat=dms(1)-rest; else lat=dms(1)+rest; end
    [dms]=sscanf(lon,'%d:%d:%d');
    rest=(dms(2)+dms(3)/60)/60;
    if dms(1)<0 lon=dms(1)-rest; else lon=dms(1)+rest; end
    coord=[lat,lon,ele];
else
    coord=[0 0 0];
end
return

%============================================
function [freq,azim,z,dz,z_hz,dz_hz] = read_mtsect(param,key)
%============================================
%pwd
par={'NFREQ','SECTID'};

for ipar=1:length(param)
    for kpar=1:length(par)
        if strmatch(param(ipar).name,char(par(kpar)))
            parval{kpar}=param(ipar).value;
        end
    end
end
nfreq=str2num(parval{1});
sectid=parval{2}(find(parval{2}~='"'));

flip=0; % for decreasing frequencies, i.e. increasing periods
for ikey=1:length(key)
    if findstr(key(ikey).name,'FREQ ') %ET 2006, one space after FREQ is needed for winglink edis
        %disp('found entry FREQ');
        freq=str2num(key(ikey).value);
        nfreq=length(freq);
        if ~isempty(key(ikey).param)
            if strcmp(key(ikey).param.name,'ORDER') && ...
                    strcmp(key(ikey).param.value,'INC');
                flip=1; % increasing frequency => increasing period wanted!
                freq=fliplr(freq);
            end
        end
        % initialize all mtsect matrices to NaN arrays, so that
        %  TF arrays can be returned by routine in any case
        %  1) only Z or HZ might be found
        %  2) entries ZXY and ZYY (e.g.) can have different
        %     lengths/periods.
        mimp=zeros(4,3,nfreq); mimp(find(mimp)==0)=NaN;
        mtip=zeros(2,3,nfreq); mtip(find(mtip)==0)=NaN;
    end
end
for ikey=1:length(key)
    if findstr(key(ikey).name,'ZROT')
        %disp('found entry ZROT')
        zrot=str2num(key(ikey).value);
        if diff(zrot)~= 0
            warning('impedances have varying azimuth!');
        end
        azim=zrot(1);
    end
end

imp = ['ZXX';'ZXY';'ZYX';'ZYY'];
riv = {'R';'I';'.VAR'};
limp=0;
for iimp=1:4
    for iriv=1:3
        for ikey=1:length(key)
            entry = [imp(iimp,:),char(riv(iriv,:))];
            if strmatch(key(ikey).name,entry)
                %disp(['found entry ',entry]);
                % check vector-length of entry
                value=str2num(key(ikey).value);
                nmax=nfreq;
                if (length(value)~=nfreq)
                    disp(['WARNING: entry-length (',num2str(length(value)),') ',...
                        'is unequal nfreq (',num2str(nfreq),')']);
                    if length(value)>nfreq
                        disp(' => only first nfreq values used!');
                        nmax=nfreq;
                    else
                        disp(' => NaN is set for last field(s)!');
                        nmax=length(value);
                    end
                end
                mimp(iimp,iriv,1:nmax)=value(1:nmax);
                if ~isempty(key(ikey).param)
                    if key(ikey).param.name=='ROT'
                        rot=key(ikey).param.value;
                        if length(rot)==5 & rot=='NORTH' azim=0; end
                    end
                end
            end
        end
    end
end

if flip==1 % increasing frequencies read => increasing periods wanted
    mimp=flipdim(mimp,3);
end
z = squeeze(mimp(:,1,:) + i*mimp(:,2,:));
%z = reshape(z,2,2,[]);
% var=variance, convert to error=standard deviation
%dz = squeeze((mimp(:,3,:)).^.5);
dz = squeeze((mimp(:,3,:))); %keep the variance

%dz = reshape(dz,2,2,[]);

tip = ['TX';'TY'];
riv = {'R.EXP';'I.EXP';'VAR.EXP'};
for itip=1:2
    for iriv=1:3
        entry = [tip(itip,:),char(riv(iriv,:))];
        for ikey=1:length(key)
            if strmatch(key(ikey).name,entry)
                %disp(['found entry ',entry]);
                % check vector-length of entry
                value=str2num(key(ikey).value);
                nmax=nfreq;
                if (length(value)~=nfreq)
                    disp(['WARNING: entry-length (',num2str(length(value)),') ',...
                        'is unequal nfreq (',num2str(nfreq),')']);
                    if length(value)>nfreq
                        disp(' => only first nfreq values used!');
                        nmax=nfreq;
                    else
                        disp(' => NaN is set for last field(s)!');
                        nmax=length(value);
                    end
                end
                mtip(itip,iriv,1:nmax)=value(1:nmax);
                if ~isempty(key(ikey).param)
                    if key(ikey).param.name=='ROT'
                        rot=key(ikey).param.value;
                        if length(rot)==5 & rot=='NORTH' azim=0; end
                    end
                end
            end
        end
    end
end
if flip==1 % increasing frequencies read => increasing periods wanted
    mtip=flipdim(mtip,3);
end
z_hz = squeeze(mtip(:,1,:) + i*mtip(:,2,:));
dz_hz = squeeze((mtip(:,3,:)).^5);

% note: different azimuths in T and Z keys are not considered.
% RHO entries are not implemented yet.

return

%============================================
function [param,key] = read_section(fid,section)
%============================================
% reads the lines of a section (output from get_section)
% creates structure arrays 'param' and 'key'
%
% |param(=)         |key(>)
%  |pname |pvalue    |kname |kvalue |kparam(=)
%                                    |kpname |kpvalue

iparam=0; ikey=0; iskey=0; vline=[];

param=struct('name',[],'value',[]);
key  =struct('name',[],'value',[],...
    'param',struct('name',[],'value',[]));
%This loop modified to read winglink edis ET 2007
for iline=2:length(section)
    line=char(section{iline});
    if line(1:1)~='>'
        linE=([' ',line]);
        % read parameters or continue reading key
        if iskey==1
            vline=strcat(vline,linE);
        elseif sum(findstr(line,'='))>1
            iparam=iparam+1;
            lindex=findstr(linE,'='); linE(lindex)=' ';
            rest=linE;
            for ipar=iparam:length(lindex)+iparam-1
                [name,rest]=strtok(rest);
                param(ipar).name=name;
                [value,rest]=strtok(rest);
                param(ipar).value=value;
            end
        end
    else
        % so it's '>' plus a keyword
        % store value of key before in case there is any (//)
        if iskey==1
            key(ikey).value=vline;
            vline=[]; iskey=0;
        end
        if findstr(line,'>END') return; end
        ikey=ikey+1;
        if findstr(line,'//') iskey=1; end
        line(1:1)=' ';
        lindex=findstr(line,'='); line(lindex)=' ';
        [name,rest]=strtok(line);
        key(ikey).name=name;
        for ikpar=1:length(lindex)
            [name,rest]=strtok(rest);
            key(ikey).param.name=name;
            [value,rest]=strtok(rest);
            key(ikey).param.value=value;
        end
    end
end

return

%============================================
function value = get_section(fid,section)
%============================================
% gets the line(s) of a section (>=)
fseek(fid,0,-1);
kline=1; line=1;
while line~=-1
    line=fgets(fid);
    if findstr(line,['>=',section])
        value{1}=line;
        line = fgets(fid);
        while line~=-1 & sum(findstr(line,'>='))==0
            kline=kline+1;
            value{kline}=line;
            line = fgets(fid);
        end
        return
    end
end
warning(['section ',section,' not found']);
return

%============================================
function value = get_key(fid,pos,key)
%============================================
% reads in the line(s) belonging to a '>' key
% starts searching at pos.
fseek(fid,pos,-1);
kline=1; line=1;
while line~=-1
    line=fgets(fid);
    if findstr(line,['>',key])
        value{1}=line;
        line = fgets(fid);
        while line~=-1 & line(1:1)~='>'
            kline=kline+1;
            value{kline}=line;
            line = fgets(fid);
        end
        return
    end
end
warning(['keyword ',key,' not found']);
return
